pub struct SimpleBiMapper<S: SphinxSuite, H: SphinxHeaderSpec>(pub(crate) BiHashMap<H::KeyId, <S::P as Keypair>::Public>);Expand description
Basic implementation of the [KeyIdMapping] trait for a simple bi-map.
Useful for testing or simple protocol implementations.
Tuple Fields
0: BiHashMap<H::KeyId, <S::P as Keypair>::Public>Trait Implementations
Sourceimpl<S: SphinxSuite, H: SphinxHeaderSpec> From<BiHashMap<<H as SphinxHeaderSpec>::KeyId, <<S as SphinxSuite>::P as Keypair>::Public>> for SimpleBiMapper<S, H>
impl<S: SphinxSuite, H: SphinxHeaderSpec> From<BiHashMap<<H as SphinxHeaderSpec>::KeyId, <<S as SphinxSuite>::P as Keypair>::Public>> for SimpleBiMapper<S, H>
Sourceimpl<S, H> KeyIdMapping<<H as SphinxHeaderSpec>::KeyId, <<S as SphinxSuite>::P as Keypair>::Public> for SimpleBiMapper<S, H>where
S: SphinxSuite,
H: SphinxHeaderSpec,
<S::P as Keypair>::Public: Eq + Hash,
H::KeyId: Eq + Hash,
impl<S, H> KeyIdMapping<<H as SphinxHeaderSpec>::KeyId, <<S as SphinxSuite>::P as Keypair>::Public> for SimpleBiMapper<S, H>where
S: SphinxSuite,
H: SphinxHeaderSpec,
<S::P as Keypair>::Public: Eq + Hash,
H::KeyId: Eq + Hash,
Sourcefn map_key_to_id(&self, key: &<S::P as Keypair>::Public) -> Option<H::KeyId>
fn map_key_to_id(&self, key: &<S::P as Keypair>::Public) -> Option<H::KeyId>
Maps public key to its unique identifier.
Sourcefn map_id_to_public(&self, id: &H::KeyId) -> Option<<S::P as Keypair>::Public>
fn map_id_to_public(&self, id: &H::KeyId) -> Option<<S::P as Keypair>::Public>
Maps public key identifier to the actual public key.
fn map_keys_to_ids(&self, keys: &[K]) -> Vec<Option<Id>>
fn map_keys_to_ids(&self, keys: &[K]) -> Vec<Option<Id>>
Convenience method to map a slice of public keys to IDs.
fn map_ids_to_keys(&self, ids: &[Id]) -> Vec<Option<K>>
fn map_ids_to_keys(&self, ids: &[Id]) -> Vec<Option<K>>
Convenience method to map a slice of IDs to public keys.